@@ -1,8 +1,9 @@
-import os
-from datetime import datetime
 import logging
+import os
+import sys
+from datetime import datetime
 
-LOGGER_MINIMUM_SEVERITY = os.getenv("LOGGER_MINIMUM_SEVERITY", "INFO")
+LOGGER_MINIMUM_SEVERITY = os.getenv("LOGGER_MINIMUM_SEVERITY", "INFO").upper()
 if LOGGER_MINIMUM_SEVERITY.isdigit():
     logger_minimum_severity = int(LOGGER_MINIMUM_SEVERITY)
     # Values from Logger.MessageSeverity
@@ -15,7 +16,8 @@ if LOGGER_MINIMUM_SEVERITY.isdigit():
     else:
         LOGGER_MINIMUM_SEVERITY = "EXCEPTION"
 
-logging.basicConfig(level=LOGGER_MINIMUM_SEVERITY)
+logging.basicConfig(level=LOGGER_MINIMUM_SEVERITY, stream=sys.stdout)
+logger = logging.getLogger(__name__)
 
 
 class MiniLogger:
@@ -32,9 +34,9 @@ class MiniLogger:
             object (dict): The object to be printed.
         """
         if object is None:
-            logging.info(f"{datetime.now()} - START - {message}")
+            logger.info(f"{datetime.now()} - START - {message}")
         else:
-            logging.info(f"{datetime.now()} - START - {message} - {object}")
+            logger.info(f"{datetime.now()} - START - {message} - {object}")
 
     @staticmethod
     def end(message: str = "", object: dict = None):
@@ -45,9 +47,9 @@ class MiniLogger:
             message (str): The message to be printed.
         """
         if object is None:
-            logging.info(f"{datetime.now()} - END - {message}")
+            logger.info(f"{datetime.now()} - END - {message}")
         else:
-            logging.info(f"{datetime.now()} - END - {message} - {object}")
+            logger.info(f"{datetime.now()} - END - {message} - {object}")
 
     @staticmethod
     def info(message: str = "", object: dict = None):
@@ -59,9 +61,9 @@ class MiniLogger:
             object (dict): The object to be printed.
         """
         if object is None:
-            logging.info(f"{datetime.now()} - INFO - {message}")
+            logger.info(f"{datetime.now()} - INFO - {message}")
         else:
-            logging.info(f"{datetime.now()} - INFO {message} - {object}")
+            logger.info(f"{datetime.now()} - INFO {message} - {object}")
 
     @staticmethod
     def warning(message: str = "", object: dict = None):
@@ -73,9 +75,9 @@ class MiniLogger:
             object (dict): The object to be printed.
         """
         if object is None:
-            logging.warning(f"{datetime.now()} - WARNING - {message}")
+            logger.warning(f"{datetime.now()} - WARNING - {message}")
         else:
-            logging.warning(f"{datetime.now()} - WARNING {message} - {object}")
+            logger.warning(f"{datetime.now()} - WARNING {message} - {object}")
 
     @staticmethod
     def error(message: str = "", object: dict = None):
@@ -87,9 +89,9 @@ class MiniLogger:
             object (dict): The object to be printed.
         """
         if object is None:
-            logging.error(f"{datetime.now()} - ERROR - {message}")
+            logger.error(f"{datetime.now()} - ERROR - {message}")
         else:
-            logging.error(f"{datetime.now()} - ERROR - {message} - {object}")
+            logger.error(f"{datetime.now()} - ERROR - {message} - {object}")
 
     @staticmethod
     def exception(message: str = "", object: Exception or dict = None):
@@ -108,6 +110,6 @@ class MiniLogger:
             exception = None
 
         if object is None:
-            logging.exception(f"{datetime.now()} - EXCEPTION - {message}")
+            logger.exception(f"{datetime.now()} - EXCEPTION - {message}")
         else:
-            logging.exception(f"{datetime.now()} - EXCEPTION- {message} - {object}", exc_info=exception)
+            logger.exception(f"{datetime.now()} - EXCEPTION- {message} - {object}", exc_info=exception)
